require('math_snippet')
require('tiles')
require('camera')

function love.load()
    tiles = init_tiles()
    selectedTile = 1
    
    camera:setBounds(0, 0, tiles.w - 512, tiles.h - 512)
end

function love.update(dt)
    
    mouse_x, mouse_y = camera:mousePosition()
    x = math.floor(mouse_x / tiles.tileW)
    y = math.floor(mouse_y / tiles.tileH)
    
    
    if love.keyboard.isDown("right") or love.keyboard.isDown("d") then
      camera:move(1, 0)
   elseif love.keyboard.isDown("left") or love.keyboard.isDown("a")then
      camera:move(-1, 0)
   end

   if love.keyboard.isDown("down") or love.keyboard.isDown("s")then
      camera:move(0, 1)
   elseif love.keyboard.isDown("up") or love.keyboard.isDown("w")then
      camera:move(0, -1)
   end
    
end


function modify_tile(selectedTile)
    tiles.tileTable[x+1][y+1] = tiles.chars[selectedTile]
end

function save_tile()
    file = love.filesystem.newFile( "map.txt" )
    file:open('w')
    local str = ''
    reversed = {}
    
    for k = 1, #tiles.tileTable[1] do
        reversed[k] = {}
    end
    
     for i = 1, #tiles.tileTable do
        for j = 1, #tiles.tileTable[i] do
            reversed[j][i] = tiles.tileTable[i][j]
        end
    end 
    
    for i = 1, #reversed do
        for j = 1, #reversed[i] do
            str = str .. reversed[i][j]
        end
        str = str  .. '\n'
    end 
    
    file:write( str )
end

function love.mousepressed(x, y, button)
   if button == 'wd' then
      if selectedTile < #tiles.chars then
            selectedTile = selectedTile + 1
      else 
            selectedTile = 1
      end
   elseif button == 'wu' then
        if selectedTile > 1 then
            selectedTile = selectedTile - 1
      else 
            selectedTile = #tiles.chars
      end
   end
   
   
   if button == 'l' then
        modify_tile(selectedTile)
   elseif button == 'r' then
        save_tile()
   end
   
end



function love.draw()

    camera:set()

    draw_tiles(tiles)
    
    love.mouse.setVisible(false)
    love.graphics.drawq(tiles.tileset, tiles.quads[tiles.chars[selectedTile]], x * tiles.tileW, y * tiles.tileH)
    
    
    love.graphics.setColor(200, 0, 0)
    love.graphics.rectangle("line", x * tiles.tileW, y * tiles.tileH, tiles.tileW, tiles.tileH)
    
    camera:unset()
end